// $Id: CaptureTool.java,v 1.1 2001/05/17 20:15:36 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.client;

import com.fooware.util.CommandLine;
import net.ultrametrics.console.TestConsole;
import net.sourceforge.jpcap.net.Packet;
import net.sourceforge.jpcap.capture.PacketListener;
import net.sourceforge.jpcap.capture.PacketCapture;
import net.sourceforge.jpcap.capture.CaptureDeviceNotFoundException;


/**
 * Tool with text console for controlling packet capture.
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.1 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/17 20:15:36 $
 */
public class CaptureTool implements PacketListener
{
  /**
   * Create a new capture tool.
   */
  public CaptureTool() {
    initializeSystem();
    initializeConsole();
  }


  // implementation of PacketListener interface

  public void packetArrived(Packet packet) {
    System.err.println("packet " + packet + " arrived");
  }


  // implementation of tool logic

  /**
   * Initialize the packet capture system.
   */
  protected void initializeSystem() {
    packetCapture = new PacketCapture();
    packetCapture.addPacketListener(this);

    try {
      System.err.println("attempting to find network device.. ");
      device = packetCapture.findDevice();
      System.err.println("using device '" + device + "'.");
    }
    catch(CaptureDeviceNotFoundException e) {
      System.err.println(e);
    }
  }

  /**
   * Initialize the tool's console.
   */
  protected void initializeConsole() {
    console = new CaptureConsole(this, packetCapture);
    // create the console's command-line processor
    CommandLine cl = new CommandLine(console); 
    cl.setPromptString("CaptureTool> ");
    cl.start();
  }

  /**
   * Set the capture device name.
   */
  public void setDevice(String device) {
    this.device = device;
  }

  /**
   * Fetch the capture device name.
   */
  public String getDevice() {
    return device;
  }

  /**
   * Packet capture.
   */
  public static void main(String [] args) {
    CaptureTool captureTool = new CaptureTool();
  }


  /**
   * The console handling commands for this capture tool.
   */
  CaptureConsole console;

  /**
   * Packet capture system.
   */
  PacketCapture packetCapture;

  /**
   * Packet capture device name.
   */
  private String device = null;


  private String _rcsid = 
    "$Id: CaptureTool.java,v 1.1 2001/05/17 20:15:36 pcharles Exp $";
}
